PickingStateMachine

Struct PickingStateMachine 

pub struct PickingStateMachine {
    pub previous: GlobalPickingState,
    pub current: GlobalPickingState,
    pub pointer: Vec2,
    pub press: Option<PressState>,
    pub current_btn_just_pressed: bool,
    pub pointer_is_out_of_bounds: bool,
    pub is_post_cancellation_state: bool,
    pub transitions: PickingTransitions,
}
Global state machine for bevy_picking.

Fields

previous: GlobalPickingState

State of the previous frame.

current: GlobalPickingState

State of the current frame.

pointer: Vec2

Pointer position.

press: Option<PressState>

If mouse is pressed, contains position, button and time of the button press.

Note

This will not be present on button release, use transitions instead.

current_btn_just_pressed: bool

If true, current button is just pressed.

pointer_is_out_of_bounds: bool

If true, PickingStateMachine::pointer is not retrieved from the current frame.

is_post_cancellation_state: bool

True if multiple valid buttons are pressed as the same time. Lasts until all valid buttons are released.

transitions: PickingTransitions

An internal event channel for picking events.

Use as_ref or iter to access items.

Implementations

Source

impl PickingStateMachine

pub fn get_state(&self, entity: Entity) -> EntityPickingState

Returns the current state on an entity.

Note
  • At most one entity have state other than EntityPickingState::None at a given frame.
  • Does not require the entity to exist.
pub fn active_state(&self) -> EntityPickingState

Returns the current state on the active entity.

pub fn get_transition(&self, entity: Entity) -> Option<PickingTransition>

Returns the current state transition event on an entity.

pub fn get_active_entity(&self) -> Option<Entity>

Returns the active entity that is being hovered or pressed.

pub fn is_hovering(&self) -> bool

Returns true if something is hovered and no recognized button is being pressed.

pub fn is_pressing(&self) -> bool

Returns true if a recognized button is pressed and not in cancellation state.

pub fn is_cancelled(&self) -> bool

Returns true if in cancellation state.