pub struct PickingStateMachinePlugin {
pub allowed_buttons: Vec<MouseButton>,
pub cancel_hover: bool,
}Expand description
Plugin for PickingStateMachine.
Fields
Only buttons in this list will be considered.
By default we only consider the left mouse button.
cancel_hover: boolIf true, pressing multiple buttons will immediately cancel Hover to None.